==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryQuestionProperties.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryQuestionComplexity;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryQuestionProperties
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryQuestionProperties.JSON_PROPERTY_COMPLEXITY })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoveryQuestionProperties implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_COMPLEXITY = "complexity";
    private PasswordPolicyRecoveryQuestionComplexity complexity;

    public PasswordPolicyRecoveryQuestionProperties() {
    }

    public PasswordPolicyRecoveryQuestionProperties complexity(PasswordPolicyRecoveryQuestionComplexity complexity) {

        this.complexity = complexity;
        return this;
    }

    /**
     * Get complexity
     *
     * @return complexity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryQuestionComplexity getComplexity() {
        return complexity;
    }

    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setComplexity(PasswordPolicyRecoveryQuestionComplexity complexity) {
        this.complexity = complexity;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryQuestionProperties passwordPolicyRecoveryQuestionProperties = (PasswordPolicyRecoveryQuestionProperties) o;
        return Objects.equals(this.complexity, passwordPolicyRecoveryQuestionProperties.complexity);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(complexity);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryQuestionProperties {\n");
        sb.append("    complexity: ").append(toIndentedString(complexity)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryQuestionProperties.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryQuestionComplexity;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryQuestionProperties
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryQuestionProperties.JSON_PROPERTY_COMPLEXITY })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PasswordPolicyRecoveryQuestionProperties implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_COMPLEXITY = "complexity";
    private PasswordPolicyRecoveryQuestionComplexity complexity;

    public PasswordPolicyRecoveryQuestionProperties() {
    }

    public PasswordPolicyRecoveryQuestionProperties complexity(PasswordPolicyRecoveryQuestionComplexity complexity) {

        this.complexity = complexity;
        return this;
    }

    /**
     * Get complexity
     *
     * @return complexity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryQuestionComplexity getComplexity() {
        return complexity;
    }

    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setComplexity(PasswordPolicyRecoveryQuestionComplexity complexity) {
        this.complexity = complexity;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryQuestionProperties passwordPolicyRecoveryQuestionProperties = (PasswordPolicyRecoveryQuestionProperties) o;
        return Objects.equals(this.complexity, passwordPolicyRecoveryQuestionProperties.complexity);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(complexity);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryQuestionProperties {\n");
        sb.append("    complexity: ").append(toIndentedString(complexity)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
